@layer wf{.SharedCopyClipboardButton[data-v-c91d971d]{position:relative}.menu[data-v-c91d971d]{width:160px}@keyframes pulse-c91d971d{0%{transform:scale(1)}50%{transform:scale(1.2)}to{transform:scale(1)}}.button.copied[data-v-c91d971d] svg{animation:pulse-c91d971d .3s ease-in-out}.button.copied[data-v-c91d971d]{color:#4caf50}}
