@layer wf{.category .header[data-v-f7960f33]{font-size:12px;font-weight:500;line-height:12px;letter-spacing:1.3px;text-transform:uppercase;color:var(--builderSecondaryTextColor);margin-bottom:8px}.tools[data-v-f7960f33]{display:grid;grid-template-columns:1fr;grid-template-rows:auto}.tool[data-v-f7960f33]{display:grid;grid-template-columns:18px 1fr;grid-template-rows:1fr;column-gap:8px;padding:8px;border-radius:4px;cursor:grab}.tool img[data-v-f7960f33]{max-width:18px;max-height:18px;aspect-ratio:1 / 1}.tool[data-v-f7960f33]:hover{background:var(--builderSubtleSeparatorColor)}.BuilderSidebarPanel__footer__autogen[data-v-f7960f33]{flex:0 0 var(--builderPanelSwitcherHeight);bottom:0;height:var(--builderPanelSwitcherHeight);display:flex;align-items:center;justify-content:center;border-top:1px solid var(--builderSeparatorColor);background:var(--builderBackgroundColor)}.BuilderSidebarPanel__footer__btn[data-v-f7960f33]{font-size:12px;font-weight:500;line-height:180%;min-width:190px}}
